@@ -1,7 +1,9 @@
 # ruff: noqa: F401
 
-import gaphor.SysML.diagramlabel
+import gaphor.SysML.deletable
 import gaphor.SysML.drop
-import gaphor.SysML.iconname
 import gaphor.SysML.modelinglanguage
+import gaphor.SysML.painter
 import gaphor.SysML.sysmlfmt
+
+__modeling_language__ = "SysML"
