@@ -1,5 +1,6 @@
-# ruff: noqa: F403
+# ruff: noqa: F401, F403
 
 from gaphor.SysML.allocations import *
 from gaphor.SysML.blocks import *
+from gaphor.SysML.diagramframe import DiagramFrameItem
 from gaphor.SysML.requirements import *
