@@ -9,7 +9,7 @@ from gaphor.UML.umlfmt import format_call_behavior_action_name
 
 
 @represents(UML.Action)
-class ActionItem(Named, ElementPresentation):
+class ActionItem(Named, ElementPresentation[UML.Action]):
     def __init__(self, diagram, id=None):
         super().__init__(diagram, id, width=50, height=30)
 
@@ -32,7 +32,7 @@ class ValueSpecificationActionItem(Valued, ElementPresentation):
         self.width = 100
         self.shape = Box(
             text_stereotypes(self, lambda: ["valueSpecification"]),
-            CssNode("value", None, Text(text=lambda: self.subject.value or "")),
+            CssNode("value", None, Text(text=lambda: self.subject.value.value or "")),
             draw=draw_border,
         )
 
