@@ -19,9 +19,14 @@ class CoreModelingLanguage(ModelingLanguage):
 
     @property
     def element_types(self):
-        return ValueError("No element types for the core model")
+        raise ValueError("No element types for the core model")
 
-    def lookup_element(self, name):
+    @property
+    def model_browser_model(self):
+        raise ValueError("No model browser model for the core model")
+
+    def lookup_element(self, name, ns=None):
+        assert ns in ("Core", None)
         return getattr(coremodel, name, None)
 
 
@@ -41,13 +46,28 @@ class MockModelingLanguage(ModelingLanguage):
 
     @property
     def diagram_types(self):
-        return ()
+        raise ValueError("No diagram types for the mock model")
 
     @property
     def element_types(self):
-        return ()
+        raise ValueError("No element types for the mock model")
+
+    @property
+    def model_browser_model(self):
+        raise ValueError("No model browser model for the mock model")
+
+    def lookup_element(self, name, ns=None):
+        if ns:
+            # This is sort of hackish.
+            # It's better to lookup modeling languages from entry points
+            for m in self._modeling_languages:
+                if m.__class__.__name__.lower().startswith(ns.lower()):
+                    return m.lookup_element(name, ns)
+
+            raise ValueError(
+                f"Invalid namespace '{ns}', should be one of {self._modeling_languages}"
+            )
 
-    def lookup_element(self, name):
         return next(
             filter(
                 None,
