@@ -8,7 +8,7 @@ from gaphas.tool.scroll import pan_tool
 import gaphor.diagram.tools.handlemove
 from gaphor.diagram.tools.dnd import drop_target_tool
 from gaphor.diagram.tools.dropzone import drop_zone_tool
-from gaphor.diagram.tools.itemtool import item_tool
+from gaphor.diagram.tools.itemtool import find_item_and_handle_at_point, item_tool
 from gaphor.diagram.tools.magnet import magnet_tool
 from gaphor.diagram.tools.placement import placement_tool
 from gaphor.diagram.tools.textedit import text_edit_tools
@@ -18,7 +18,9 @@ from gaphor.diagram.tools.txtool import transactional_tool
 def apply_default_tool_set(view, modeling_language, event_manager, rubberband_state):
     """The default tool set."""
     view.remove_all_controllers()
-    view.add_controller(hover_tool())
+    view.add_controller(
+        hover_tool(find_item_and_handle_at_point=find_item_and_handle_at_point)
+    )
     view.add_controller(*text_edit_tools(event_manager))
     view.add_controller(
         *transactional_tool(item_tool(event_manager), event_manager=event_manager)
