@@ -10,7 +10,6 @@ import sys
 
 from gi.repository import Adw
 
-from gaphor.asyncio import response_from_adwaita_dialog
 from gaphor.i18n import gettext
 
 
@@ -33,7 +32,7 @@ async def error_dialog(message, secondary_message="", window=None):
         dialog.set_default_response("close")
     dialog.set_close_response("close")
 
-    answer = await response_from_adwaita_dialog(dialog, window)
+    answer = await dialog.choose(window)
 
     if exc_traceback and answer in (100, "debug"):
         pdb.post_mortem(exc_traceback)
